pub enum MemoryStatus {
Current,
Unbound,
Stale,
Superseded,
Invalidated,
}Expand description
Durable retrieval lifecycle of one context item.
Variants
Current
Bound to the latest workspace state observed by the runtime.
Unbound
Not bound to a workspace state and therefore never current evidence.
Stale
Invalidated by a later observed workspace state.
Superseded
Replaced by a newer context item.
Invalidated
Explicitly invalidated by the runtime.