pub enum SecretTaint {
None,
Redacted,
}Expand description
Public indication that sensitive input was removed before persistence.
Variants
None
No configured secret matched the persisted public statement.
Redacted
Sensitive material matched and only a redacted statement was retained.