pub struct ProofEvaluation {
pub claim_scope: ClaimScope,
pub assurance_level: AssuranceLevel,
pub outcome: RunOutcome,
pub criteria: Vec<CriterionEvaluation>,
}Expand description
Deterministic result of reducing a contract and proof graph.
Fields
claim_scope: ClaimScopeClaim made by this evaluation.
assurance_level: AssuranceLevelLowest assurance among the evidence supporting required passed criteria.
outcome: RunOutcomeCompletion-gate result.
criteria: Vec<CriterionEvaluation>Per-criterion derivation details.