EventEnvelope

Struct EventEnvelope 

pub struct EventEnvelope {
    pub schema_version: String,
    pub session_id: Uuid,
    pub seq: u64,
    pub timestamp: DateTime<Utc>,
    pub kind: String,
    pub payload: Value,
    pub prev_hash: Option<String>,
    pub hash: String,
}
One append-only, hash-chained session event.

Fields

schema_version: String

External schema version.

session_id: Uuid

Session identifier.

seq: u64

Zero-based monotonic event sequence.

timestamp: DateTime<Utc>

Event timestamp.

kind: String

Extensible dotted event name.

payload: Value

Event-specific public payload.

prev_hash: Option<String>

Hash of the previous event, absent for the genesis event.

hash: String

BLAKE3 digest of canonical hash material.

Implementations

Source

impl EventEnvelope

pub fn new( session_id: Uuid, seq: u64, kind: impl Into<String>, payload: Value, prev_hash: Option<String>, ) -> Self

Creates an event using the current UTC time.

pub fn new_at( session_id: Uuid, seq: u64, timestamp: DateTime<Utc>, kind: impl Into<String>, payload: Value, prev_hash: Option<String>, ) -> Self

Creates an event at a supplied time, primarily for deterministic fixtures.

pub fn verify_hash(&self) -> bool

Verifies this event’s digest without looking at neighbors.